function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import { clearFix } from 'polished';
import { Link } from '@cloudflare/component-link';
import { Icon as OriginalIcon } from '@cloudflare/component-icon';
import { createStyledComponent, createComponent } from '@cloudflare/style-container';
import { VisuallyHiddenSpan } from '@cloudflare/component-visually-hidden';
import { Trans } from '@cloudflare/intl-react';
var noBarSpace = '12px';

var styles = () => ({
  position: 'relative',
  width: '100%'
});

var Bar = createComponent(_ref => {
  var {
    theme
  } = _ref;
  return {
    display: 'block',
    width: '100%',
    appearance: 'none',
    '&::-webkit-progress-bar': {
      backgroundColor: theme.colors.gray[8],
      color: theme.colors.gray[8]
    },
    '&::-webkit-progress-value': {
      backgroundColor: theme.colors.blue[4],
      color: theme.colors.blue[4],
      transition: 'width 500ms ease'
    },

    /* Mozilla uses progress-bar as the value */
    '&::-moz-progress-bar': {
      backgroundColor: theme.colors.blue[4],
      color: theme.colors.blue[4]
    }
  };
}, 'progress');
var Icon = createStyledComponent(_ref2 => {
  var {
    hide
  } = _ref2;
  return {
    visibility: hide ? 'hidden' : 'visible'
  };
}, OriginalIcon);
var Items = createStyledComponent(() => _objectSpread(_objectSpread({
  listStyle: 'none'
}, clearFix()), {}, {
  margin: 0,
  padding: 0
}), 'ol');
var Item = createStyledComponent(_ref3 => {
  var {
    theme,
    width,
    disabled,
    active,
    showBar
  } = _ref3;
  var color = theme.colors.gray[4];

  if (disabled) {
    color = theme.colors.gray[7];
  } else if (active) {
    color = theme.colors.blue[4];
  }

  return {
    width: 'auto',
    float: 'none',
    height: 'auto',
    paddingBottom: 0,
    paddingLeft: 0,
    paddingRight: 0,
    paddingTop: showBar ? theme.space[2] : 0,
    color,
    fontSize: theme.fontSizes[3],
    fontWeight: active ? theme.weightBold : theme.fontWeight,
    textAlign: 'center',
    cursor: disabled ? 'default' : 'pointer',
    display: active ? 'list-item' : 'none',
    '&::before': {
      content: 'none'
    },
    tablet: {
      width,
      float: 'left',
      display: 'list-item'
    }
  };
}, 'li');

class Progress extends React.Component {
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
  }

  handleClick(step) {
    if (step.id !== this.props.active) {
      this.props.onChange && this.props.onChange(step.id);
    }
  }

  render() {
    var {
      className,
      steps,
      active,
      showBar,
      isStepEnabled
    } = this.props;
    var max = steps.length;
    var itemWidth = (1 / max * 100).toFixed(4) + '%';
    var value;
    var items = steps.map((step, index) => {
      var isActive = step.id === active;
      var isDisabled = isStepEnabled ? !isStepEnabled(step) : step.disabled;
      var isLastStep = index + 1 === steps.length;
      var lastStepId = 'last-progress-step';

      if (isActive) {
        value = index + 1;
      }

      return /*#__PURE__*/React.createElement(Item, {
        key: step.id,
        width: showBar ? itemWidth : 'auto',
        disabled: step.disabled,
        active: isActive
      }, isLastStep && /*#__PURE__*/React.createElement(VisuallyHiddenSpan, {
        id: lastStepId
      }, /*#__PURE__*/React.createElement(Trans, {
        _: "Last step.",
        id: "accessibility.progressbar.last_step"
      })), /*#__PURE__*/React.createElement(Link, {
        onClick: this.handleClick.bind(null, step),
        disabled: isDisabled,
        pr: showBar ? 0 : noBarSpace,
        "aria-current": isActive ? 'step' : undefined,
        "aria-disabled": isDisabled,
        "aria-describedby": isLastStep ? lastStepId : undefined,
        style: {
          textDecoration: isActive ? 'underline' : 'none'
        }
      }, step.label), !showBar && /*#__PURE__*/React.createElement(Icon, {
        type: "right",
        color: "gray.5",
        pr: noBarSpace,
        size: 32,
        mb: "-11px",
        hide: index === steps.length - 1,
        label: ""
      }));
    });
    return /*#__PURE__*/React.createElement("div", {
      className: className
    }, this.props.showBar && /*#__PURE__*/React.createElement(Bar, {
      max: max,
      value: value
    }), /*#__PURE__*/React.createElement(Items, null, items));
  }

}

Progress.propTypes = {
  active: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
  onChange: PropTypes.func,
  steps: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
    label: PropTypes.node.isRequired,
    disabled: PropTypes.bool
  })).isRequired,
  className: PropTypes.string,
  showBar: PropTypes.bool,
  isStepEnabled: PropTypes.func
};
Progress.defaultProps = {
  steps: [],
  showBar: true
};
Progress.displayName = 'Progress';
export default createStyledComponent(styles, Progress);